tlslite.integration.AsyncStateMachine.AsyncStateMachine

Package tlslite :: Package integration :: Module AsyncStateMachine :: Class AsyncStateMachine |
[show private | hide private]
[frames | no frames]

## Class AsyncStateMachine

Known Subclasses:
  `TLSAsyncDispatcherMixIn`, `TLSTwistedProtocolWrapper`

This is an abstract class that's used to integrate TLS Lite with asyncore and Twisted.

This class signals wantsReadsEvent() and wantsWriteEvent(). When the underlying socket has become readable or writeable, the event should be passed to this class by calling inReadEvent() or inWriteEvent(). This class will then try to read or write through the socket, and will update its state appropriately.

This class will forward higher-level events to its subclass. For example, when a complete TLS record has been received, outReadEvent() will be called with the decrypted data.

Method Summary
| `__init__(self)`
| ``inReadEvent`(self)` Tell the state machine it can read from the socket.
| ``inWriteEvent`(self)` Tell the state machine it can write to the socket.
| ``outCloseEvent`(self)` Called when a close operation completes.
| ``outConnectEvent`(self)` Called when a handshake operation completes.
| ``outReadEvent`(self, readBuffer)` Called when a read operation completes.
| ``outWriteEvent`(self)` Called when a write operation completes.
| ``setCloseOp`(self)` Start a close operation.
| ``setHandshakeOp`(self, handshaker)` Start a handshake operation.
| ``setServerHandshakeOp`(self, **args)` Start a handshake operation.
| ``setWriteOp`(self, writeBuffer)` Start a write operation.
bool or None | ``wantsReadEvent`(self)` If the state machine wants to read.
bool or None | ``wantsWriteEvent`(self)` If the state machine wants to write.

Method Details

### inReadEvent(self) Tell the state machine it can read from the socket.

### inWriteEvent(self) Tell the state machine it can write to the socket.

### outCloseEvent(self) Called when a close operation completes. May be overridden in subclass.

### outConnectEvent(self) Called when a handshake operation completes. May be overridden in subclass.

### outReadEvent(self, readBuffer) Called when a read operation completes. May be overridden in subclass.

### outWriteEvent(self) Called when a write operation completes. May be overridden in subclass.

### setCloseOp(self) Start a close operation.

### setHandshakeOp(self, handshaker) Start a handshake operation. Parameters: `handshaker` - A generator created by using one of the asynchronous handshake functions (i.e. handshakeServerAsync, or handshakeClientxxx(..., async=True). (type=generator)

### setServerHandshakeOp(self, **args) Start a handshake operation. The arguments passed to this function will be forwarded to `tlslite.TLSConnection.TLSConnection.handshakeServerAsync`.

### setWriteOp(self, writeBuffer) Start a write operation. Parameters: `writeBuffer` - The string to transmit. (type=str)

### wantsReadEvent(self) If the state machine wants to read. If an operation is active, this returns whether or not the operation wants to read from the socket. If an operation is not active, this returns None. Returns: If the state machine wants to read. (type=bool or None)

### wantsWriteEvent(self) If the state machine wants to write. If an operation is active, this returns whether or not the operation wants to write to the socket. If an operation is not active, this returns None. Returns: If the state machine wants to write. (type=bool or None)

Generated by Epydoc 2.0 on Mon Feb 21 21:56:55 2005 | http://epydoc.sf.net